==> haskell-authenticate-1.3.5.2-238-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-GhvnaMetKITFClMXEkhywp
key:                  authenticate-1.3.5.2-GhvnaMetKITFClMXEkhywp
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  2617eb4f595226e277d735548b84794e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-GhvnaMetKITFClMXEkhywp
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    attoparsec-aeson-2.1.0.0-4vY3J0brPwKGduZzr9qLSE base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q containers-0.6.7
    html-conduit-1.3.2.2-IprXQWrCGDdIDLJq1h9sjc
    http-conduit-2.3.9.1-5P1WHi6SLyo9dv1b5uZb0k
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    xml-conduit-1.9.1.4-1cCl4mnX5as2ZihXQ5w8FO

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-239-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-4gHHq42jnLv6OeH4fuBHVP
key:                  authenticate-1.3.5.2-4gHHq42jnLv6OeH4fuBHVP
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  1fb9bc2260d88148543b93ed26e01b6e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-4gHHq42jnLv6OeH4fuBHVP
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    attoparsec-aeson-2.1.0.0-4vY3J0brPwKGduZzr9qLSE base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q containers-0.6.7
    html-conduit-1.3.2.2-gBbL9948s3GGv8AJAYYVF
    http-conduit-2.3.9.1-HKTEHoMQbVODlt9daK23ia
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    xml-conduit-1.9.1.4-4ApAZ67Z6lCGy52B3tehMj

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
